#----------------------------------------------------------
#Function for the event procedure
#----------------------------------------------------------
use mwt;
$count = 1;
sub btnop {
	my ($object) = @_;
	#do something...
	$object->setProperty("labelString","hello!");
	$count +=1;
	$str = "Btn pressed: $count";
	$newvlab_002->setProperty("labelString",$str);
}
1;
